Functions
=========

.. autofunction:: ppx.find_project
.. autofunction:: ppx.get_data_dir
.. autofunction:: ppx.set_data_dir
.. autofunction:: ppx.pride.list_projects
.. autofunction:: ppx.massive.list_projects
